Method: Selenium::SeleniumDriver#get_attribute

Defined in:
lib/selenium/openqa/selenium.rb

#get_attribute(attributeLocator) ⇒ Object

Gets the value of an element attribute. The value of the attribute may differ across browsers (this is the case for the “style” attribute, for example).

‘attributeLocator’ is an element locator followed by an @ sign and then the name of the attribute, e.g. “foo@bar”



1091
1092
1093
# File 'lib/selenium/openqa/selenium.rb', line 1091

def get_attribute(attributeLocator)
    return get_string("getAttribute", [attributeLocator,])
end